from __future__ import annotations

from collections.abc import Generator
from contextlib import contextmanager
from typing import Callable

from django.test.utils import modify_settings

from corsheaders.signals import check_request_enabled


def add_middleware(action: str, path: str) -> modify_settings:
    return modify_settings(**{"MIDDLEWARE": {action: path}})


def prepend_middleware(path: str) -> modify_settings:
    return add_middleware("prepend", path)


@contextmanager
def temporary_check_request_hander(handler: Callable[..., bool]) -> Generator[None]:
    check_request_enabled.connect(handler)
    try:
        yield
    finally:
        check_request_enabled.disconnect(handler)



from __future__ import annotations

from http import HTTPStatus

from django.http import HttpResponse
from django.views.decorators.http import require_GET


@require_GET
def index(request):
    return HttpResponse("Index")


async def async_(request):
    return HttpResponse("Asynchronous")


def unauthorized(request):
    return HttpResponse("Unauthorized", status=HTTPStatus.UNAUTHORIZED)


def delete_enabled_attribute(request):
    del request._cors_enabled
    return HttpResponse()
